aboutsummaryrefslogtreecommitdiffstats
path: root/epan/dissectors/packet-cups.c
diff options
context:
space:
mode:
authorGuy Harris <guy@alum.mit.edu>2015-02-21 12:39:00 -0800
committerGuy Harris <guy@alum.mit.edu>2015-02-21 20:39:25 +0000
commitbfb432729156378d2f8fc8b666fda7e7b23e9749 (patch)
tree4c3e85ba30ff41319e48563ee0063c7b6e990f6c /epan/dissectors/packet-cups.c
parentf3a68f00a1a9b7a3f28c6986713febaa81b92ba0 (diff)
Remove tvb_ from the names of wsutil mempbrk routines.
Routines that don't take a tvbuff as an argument shouldn't have tvb_ in the name. Change-Id: I3550256551e30b3f329cbbfca71ef27c727d29c0 Reviewed-on: https://code.wireshark.org/review/7302 Reviewed-by: Guy Harris <guy@alum.mit.edu>
Diffstat (limited to 'epan/dissectors/packet-cups.c')
-rw-r--r--epan/dissectors/packet-cups.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/epan/dissectors/packet-cups.c b/epan/dissectors/packet-cups.c
index 42359bb741..ad6ab5892f 100644
--- a/epan/dissectors/packet-cups.c
+++ b/epan/dissectors/packet-cups.c
@@ -103,8 +103,8 @@ static int hf_cups_make_model = -1;
static gint ett_cups = -1;
static gint ett_cups_ptype = -1;
-/* patterns used for tvb_pbrk_pattern_guint8 */
-static tvb_pbrk_pattern pbrk_whitespace;
+/* patterns used for tvb_ws_mempbrk_pattern_guint8 */
+static ws_mempbrk_pattern pbrk_whitespace;
/* This protocol is heavily related to IPP, but it is CUPS-specific
and non-standard. */
@@ -289,7 +289,7 @@ get_unquoted_string(tvbuff_t *tvb, gint offset, gint *next_offset, guint *len)
guint l = 0;
gint o;
- o = tvb_pbrk_pattern_guint8(tvb, offset, -1, &pbrk_whitespace, NULL);
+ o = tvb_ws_mempbrk_pattern_guint8(tvb, offset, -1, &pbrk_whitespace, NULL);
if (o != -1) {
l = o - offset;
s = tvb_get_string_enc(wmem_packet_scope(), tvb, offset, l, ENC_ASCII);
@@ -394,7 +394,7 @@ proto_register_cups(void)
proto_register_subtree_array(ett, array_length(ett));
/* compile patterns */
- tvb_pbrk_compile(&pbrk_whitespace, " \t\r\n");
+ ws_mempbrk_compile(&pbrk_whitespace, " \t\r\n");
}
void